@@ -158,6 +158,20 @@ class Path(object):
         for c, e in zip(colors, self.entities):
             e.color = c
 
+    def colors_crc(self):
+        """
+        A CRC of the current entity colors.
+
+        Returns
+        -------
+        crc : int
+          CRC of the current entity colors
+        """
+        # first CRC the colors in every entity
+        target = caching.crc32(bytes().join(
+            e.color.tobytes() for e in self.entities))
+        return target
+
     @property
     def vertices(self):
         return self._vertices
@@ -1489,7 +1503,7 @@ class Path2D(Path):
         Return an MD5 of the identifier
         """
         as_int = (self.identifier * 1e4).astype(np.int64)
-        hashed = util.md5_object(as_int.tostring(order='C'))
+        hashed = util.md5_object(as_int.tobytes(order='C'))
         return hashed
 
     @property
