@@ -226,7 +226,7 @@ class SceneViewer(pyglet.window.Window):
         args = rendering.convert_to_vertexlist(geometry, **kwargs)
         # create the indexed vertex list
         self.vertex_list[name] = self.batch.add_indexed(*args)
-        # save the MD5 of the geometry
+        # save the hash of the geometry
         self.vertex_list_hash[name] = geometry_hash(geometry)
         # save the rendering mode from the constructor args
         self.vertex_list_mode[name] = args[1]
@@ -798,7 +798,7 @@ class SceneViewer(pyglet.window.Window):
 
 def geometry_hash(geometry):
     """
-    Get an MD5 for a geometry object
+    Get a hash for a geometry object
 
     Parameters
     ------------
@@ -806,19 +806,25 @@ def geometry_hash(geometry):
 
     Returns
     ------------
-    MD5 : str
+    hash : str
     """
-    if hasattr(geometry, 'md5'):
+    if hasattr(geometry, 'crc'):
         # for most of our trimesh objects
-        md5 = geometry.md5()
+        h = str(geometry.crc())
+    elif hasattr(geometry, 'md5'):
+        h = geometry.md5()
     elif hasattr(geometry, 'tostring'):
         # for unwrapped ndarray objects
-        md5 = str(hash(geometry.tostring()))
+        h = str(hash(geometry.tostring()))
 
     if hasattr(geometry, 'visual'):
         # if visual properties are defined
-        md5 += str(geometry.visual.crc())
-    return md5
+        h += str(geometry.visual.crc())
+    elif hasattr(geometry, 'visual_crc'):
+        # paths do not use the visual attribute
+        h += str(geometry.colors_crc())
+
+    return h
 
 
 def render_scene(scene,
